---
home: true
heroImage: /reacnetgen.svg
heroText: ReacNetGenerator
tagline: 基于反应分子动力学模拟轨迹的反应网络自动构建和可视化软件
actionText: 快速上手
actionLink: guide/
features:
- title: 轨迹
  details: 处理包含原子坐标或键级的轨迹
- title: 过滤
  details: 基于隐马尔科夫模型的噪声过滤
- title: 同分异构体
  details: 根据 SMILES 识别同分异构体
- title: 网络
  details: 使用力引导算法生成反应网络
- title: HTML5
  details: 展示可交互的网页结果
- title: 快速
  details: 包含并行计算和性能优化
footer: Copyright © 2018-2019 East China Normal University
---

<div class="bilitube" data-youtube="TI21SI9YPfo" data-bvid="BV175411N7uG">Loading...</div>

# 引用和联系方式

ReacNetGenerator: an automatic reaction network generator for reactive molecular dynamic simulations, Phys. Chem. Chem. Phys., 2020, 22 (2): 683–691, doi: [10.1039/C9CP05091D](https://dx.doi.org/10.1039/C9CP05091D)

jinzhe.zeng@rutgers.edu (Jinzhe Zeng), tzhu@lps.ecnu.edu.cn (Tong Zhu)

# 指南和教程

我们提供了[使用指南](guide/)，包括如何安装和使用ReacNetGenerator。我们也提供了[一系列教程](../tutorial/)来帮助你使用ReacNetGenerator。

# 荣誉
* 2019年（第十一届）上海市大学生计算机应用能力大赛一等奖
* 2019年（第12届）中国大学生计算机设计大赛一等奖

# 致谢
* 国家自然科学基金（编号91641116）
* 国家大学生创新创业训练计划项目（201910269080）
* 华东师范大学仪器共享平台（001号）

<bilitubescript />
